Feedforward Closedloop Learning: Member List

Feedforward Closedloop Learning

feedforward_closedloop_learning.Neuron Member List

This is the complete list of members for feedforward_closedloop_learning.Neuron, including all inherited members.

__init__(self, "int" _nInputs) | feedforward_closedloop_learning.Neuron |
calcOutput(self) | feedforward_closedloop_learning.Neuron |
calcOutputThread("void *" object) | feedforward_closedloop_learning.Neuron | static
CONST_WEIGHTS (defined in feedforward_closedloop_learning.Neuron) | feedforward_closedloop_learning.Neuron | static
dActivation(self) | feedforward_closedloop_learning.Neuron |
doLearning(self) | feedforward_closedloop_learning.Neuron |
doLearningThread("void *" object) | feedforward_closedloop_learning.Neuron | static
doMaxDet(self) | feedforward_closedloop_learning.Neuron |
doMaxDetThread("void *" object) | feedforward_closedloop_learning.Neuron | static
getAverageOfWeightVector(self) | feedforward_closedloop_learning.Neuron |
getBiasWeight(self) | feedforward_closedloop_learning.Neuron |
getDecay(self) | feedforward_closedloop_learning.Neuron |
getError(self) | feedforward_closedloop_learning.Neuron |
getEuclideanNormOfWeightVector(self) | feedforward_closedloop_learning.Neuron |
getInfinityNormOfWeightVector(self) | feedforward_closedloop_learning.Neuron |
getInput(self, "int" _index) | feedforward_closedloop_learning.Neuron |
getManhattanNormOfWeightVector(self) | feedforward_closedloop_learning.Neuron |
getMask(self, *args) | feedforward_closedloop_learning.Neuron |
getMaxWeightValue(self) | feedforward_closedloop_learning.Neuron |
getMinWeightValue(self) | feedforward_closedloop_learning.Neuron |
getNinputs(self) | feedforward_closedloop_learning.Neuron |
getOutput(self) | feedforward_closedloop_learning.Neuron |
getSum(self) | feedforward_closedloop_learning.Neuron |
getSumOfSquaredWeightVector(self) | feedforward_closedloop_learning.Neuron |
getWeight(self, "int" _index) | feedforward_closedloop_learning.Neuron |
getWeightDistanceFromInitialWeights(self) | feedforward_closedloop_learning.Neuron |
initWeights(self, *args) | feedforward_closedloop_learning.Neuron |
LINEAR (defined in feedforward_closedloop_learning.Neuron) | feedforward_closedloop_learning.Neuron | static
MAX_OUTPUT_CONST (defined in feedforward_closedloop_learning.Neuron) | feedforward_closedloop_learning.Neuron | static
MAX_OUTPUT_RANDOM (defined in feedforward_closedloop_learning.Neuron) | feedforward_closedloop_learning.Neuron | static
MAX_WEIGHT_RANDOM (defined in feedforward_closedloop_learning.Neuron) | feedforward_closedloop_learning.Neuron | static
normaliseWeights(self, "double" norm) | feedforward_closedloop_learning.Neuron |
RELU (defined in feedforward_closedloop_learning.Neuron) | feedforward_closedloop_learning.Neuron | static
REMAXLU (defined in feedforward_closedloop_learning.Neuron) | feedforward_closedloop_learning.Neuron | static
saveInitialWeights(self) | feedforward_closedloop_learning.Neuron |
setActivationFunction(self, "Neuron::ActivationFunction" _activationFunction) | feedforward_closedloop_learning.Neuron |
setBias(self, "double" _bias) | feedforward_closedloop_learning.Neuron |
setBiasWeight(self, "double" _biasweight) | feedforward_closedloop_learning.Neuron |
setDebugInfo(self, "int" _layerIndex, "int" _neuronIndex) | feedforward_closedloop_learning.Neuron |
setDecay(self, "double" _decay) | feedforward_closedloop_learning.Neuron |
setError(self, "double" _error) | feedforward_closedloop_learning.Neuron |
setGeometry(self, "int" _width, "int" _height) | feedforward_closedloop_learning.Neuron |
setInput(self, "int" _index, "double" _value) | feedforward_closedloop_learning.Neuron |
setLearningRate(self, "double" _learningrate) | feedforward_closedloop_learning.Neuron |
setMask(self, *args) | feedforward_closedloop_learning.Neuron |
setMomentum(self, "double" _momentum) | feedforward_closedloop_learning.Neuron |
setStep(self, "long" _step) | feedforward_closedloop_learning.Neuron |
setWeight(self, "int" _index, "double" _weight) | feedforward_closedloop_learning.Neuron |
TANH (defined in feedforward_closedloop_learning.Neuron) | feedforward_closedloop_learning.Neuron | static
TANHLIMIT (defined in feedforward_closedloop_learning.Neuron) | feedforward_closedloop_learning.Neuron | static
thisown (defined in feedforward_closedloop_learning.Neuron) | feedforward_closedloop_learning.Neuron | static